pub struct BuildConfig { /* private fields */ }Implementations
Sourceimpl BuildConfig
impl BuildConfig
pub fn from_spec(spec: &ConfigSpec) -> Self
Sourcepub fn pragma(&mut self, pragma: impl Into<String>) -> &mut Self
pub fn pragma(&mut self, pragma: impl Into<String>) -> &mut Self
Register an additional attribute name that should be treated like #[pragma(...)].
Sourcepub fn derive(
&mut self,
name: impl Into<String>,
template: impl AsRef<str>,
) -> &mut Self
pub fn derive( &mut self, name: impl Into<String>, template: impl AsRef<str>, ) -> &mut Self
Register a custom derive name and its mustache template expansion.
pub fn module_derive( &mut self, extension: impl Into<String>, configure: impl FnOnce(&mut ModuleDeriveBuilder), ) -> &mut Self